==> mule-oauth-client-api-2.0.0-sources.jar: org/mule/oauth/client/api/AuthorizationCodeOAuthDancer.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.oauth.client.api;

import org.mule.api.annotation.NoImplement;
import org.mule.oauth.client.api.exception.RequestAuthenticationException;
import org.mule.oauth.client.api.listener.AuthorizationCodeListener;
import org.mule.oauth.client.api.state.ResourceOwnerOAuthContext;
import org.mule.runtime.http.api.domain.message.request.HttpRequest;
import org.mule.runtime.http.api.server.async.HttpResponseReadyCallback;

import java.util.concurrent.CompletableFuture;

/**
 * Implementations provide OAuth dance support for authorization-code grant-type.
 *
 * @since 1.0
 */
@NoImplement
public interface AuthorizationCodeOAuthDancer {

  /**
   * Will query the internal state (the {@code tokensStore} parameter passed to the service to build the
   * {@link AuthorizationCodeOAuthDancer}) to get the appropriate accessToken. This requires that the authorization has been
   * performed beforehand, otherwise, a {@link RequestAuthenticationException} will be thrown.
   *
   * @param resourceOwner The resource owner to get the token for.
   * @return a future with the token to send on the authorized request. This will be immediately available unless a refresh has to
   *         be made.
   * @throws RequestAuthenticationException if called for a {@code resourceOwner} that has not yet been authorized.
   */
  CompletableFuture<String> accessToken(String resourceOwner) throws RequestAuthenticationException;

  /**
   * Performs the refresh of the access token.
   *
   * @param resourceOwner The resource owner to get the token for.
   * @return a completable future that is complete when the token has been refreshed.
   */
  CompletableFuture<Void> refreshToken(String resourceOwner);

  /**
   * Performs the refresh of the access token.
   *
   * @param resourceOwner      The resource owner to get the token for.
   * @param useQueryParameters If the parameters needed to refresh the token should be sent as query parameters. If false, they
   *                           will be sent encoded in the body of the message.
   * @return a completable future that is complete when the token has been refreshed.
   */
  default CompletableFuture<Void> refreshToken(String resourceOwner, boolean useQueryParameters) {
    return refreshToken(resourceOwner);
  }

  /**
   * Clears the oauth context for a given user.
   *
   * @param resourceOwnerId id of the user.
   */
  void invalidateContext(String resourceOwnerId);

  /**
   * Retrieves the oauth context for a particular user. If there's no state for that user a new state is retrieved so never
   * returns null.
   *
   * @param resourceOwnerId id of the user.
   * @return oauth state
   */
  ResourceOwnerOAuthContext getContextForResourceOwner(final String resourceOwnerId);

  /**
   * Handles an http request that will redirect to the access page in {@code authorizationUrl} with the configured credentials.
   *
   * @param request          the request from the user to login and/or authorize the application
   * @param responseCallback the callback where the response with the redirection to the login/authorization page will be sent
   */
  void handleLocalAuthorizationRequest(HttpRequest request, HttpResponseReadyCallback responseCallback);

  /**
   * Adds the {@code listener}. Listeners will be invoked in the same order as they were added
   *
   * @param listener the {@link AuthorizationCodeListener} to be added
   * @throws IllegalArgumentException if the {@code listener} is {@code null}
   * @deprecated since 1.1, 1.0.2. Use {@link #addListener(String, AuthorizationCodeListener)} instead to properly handle the
   *             events corresponding to a resource owner
   */
  @Deprecated
  void addListener(AuthorizationCodeListener listener);

  /**
   * Removes the {@code listener}. Nothing happens if it wasn't part of {@code this} dancer.
   *
   * @param listener the {@link AuthorizationCodeListener} to be removed
   * @throws IllegalArgumentException if the {@code listener} is {@code null}
   * @deprecated since 1.1, 1.0.2. Use {@link #addListener(String, AuthorizationCodeListener)} instead
   */
  @Deprecated
  void removeListener(AuthorizationCodeListener listener);

  /**
   * Adds the {@code listener}. Listeners will be invoked in the same order as they were added
   *
   * @param resourceOwnerId id of the user who the listener corresponds to
   * @param listener        the {@link AuthorizationCodeListener} to be added
   * @throws IllegalArgumentException if the {@code listener} is {@code null}
   *
   * @since 1.1, 1.0.2
   */
  default void addListener(String resourceOwnerId, AuthorizationCodeListener listener) {
    addListener(listener);
  }

  /**
   * Removes the {@code listener}. Nothing happens if it wasn't part of {@code this} dancer.
   *
   * @param resourceOwnerId id of the user who the listener corresponds to
   * @param listener        the {@link AuthorizationCodeListener} to be removed
   * @throws IllegalArgumentException if the {@code listener} is {@code null}
   *
   * @since 1.1, 1.0.2
   */
  default void removeListener(String resourceOwnerId, AuthorizationCodeListener listener) {
    removeListener(listener);
  }

}

==> mule-oauth-client-api-2.4.12-20251024.232644-3-sources.jar: org/mule/oauth/client/api/AuthorizationCodeOAuthDancer.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.oauth.client.api;

import org.mule.api.annotation.NoImplement;
import org.mule.oauth.client.api.exception.RequestAuthenticationException;
import org.mule.oauth.client.api.listener.AuthorizationCodeListener;
import org.mule.oauth.client.api.state.ResourceOwnerOAuthContext;
import org.mule.runtime.http.api.domain.message.request.HttpRequest;
import org.mule.runtime.http.api.server.async.HttpResponseReadyCallback;

import java.util.concurrent.CompletableFuture;

/**
 * Implementations provide OAuth dance support for authorization-code grant-type.
 *
 * @since 1.0
 */
@NoImplement
public interface AuthorizationCodeOAuthDancer {

  /**
   * Will query the internal state (the {@code tokensStore} parameter passed to the service to build the
   * {@link AuthorizationCodeOAuthDancer}) to get the appropriate accessToken. This requires that the authorization has been
   * performed beforehand, otherwise, a {@link RequestAuthenticationException} will be thrown.
   *
   * @param resourceOwner The resource owner to get the token for.
   * @return a future with the token to send on the authorized request. This will be immediately available unless a refresh has to
   *         be made.
   * @throws RequestAuthenticationException if called for a {@code resourceOwner} that has not yet been authorized.
   */
  CompletableFuture<String> accessToken(String resourceOwner) throws RequestAuthenticationException;

  /**
   * Performs the refresh of the access token.
   *
   * @param resourceOwner The resource owner to get the token for.
   * @return a completable future that is complete when the token has been refreshed.
   */
  CompletableFuture<Void> refreshToken(String resourceOwner);

  /**
   * Performs the refresh of the access token.
   *
   * @param resourceOwner      The resource owner to get the token for.
   * @param useQueryParameters If the parameters needed to refresh the token should be sent as query parameters. If false, they
   *                           will be sent encoded in the body of the message.
   * @return a completable future that is complete when the token has been refreshed.
   */
  default CompletableFuture<Void> refreshToken(String resourceOwner, boolean useQueryParameters) {
    return refreshToken(resourceOwner);
  }

  /**
   * Clears the oauth context for a given user.
   *
   * @param resourceOwnerId ID of the user.
   */
  void invalidateContext(String resourceOwnerId);

  /**
   * Clears the oauth context for a given user. The parameter forceInvalidateStatusRetrieval has been added to the existing method
   * to handle situations that require the invalidation status to be synchronized across all nodes in a cluster.
   *
   * @param resourceOwnerId                ID of the user.
   * @param forceInvalidateStatusRetrieval specifies whether the current token status should be forcefully invalidated and
   *                                       retrieved again. If set to true, the system will disregard any cached status and
   *                                       perform a fresh check of the token status.
   *
   * @since 2.3.0
   */
  void invalidateContext(String resourceOwnerId, boolean forceInvalidateStatusRetrieval);

  /**
   * Retrieves the oauth context for a particular user. If there's no state for that user a new state is retrieved so never
   * returns null.
   *
   * @param resourceOwnerId id of the user.
   * @return oauth state
   */
  ResourceOwnerOAuthContext getContextForResourceOwner(final String resourceOwnerId);

  /**
   * Handles an http request that will redirect to the access page in {@code authorizationUrl} with the configured credentials.
   *
   * @param request          the request from the user to login and/or authorize the application
   * @param responseCallback the callback where the response with the redirection to the login/authorization page will be sent
   */
  void handleLocalAuthorizationRequest(HttpRequest request, HttpResponseReadyCallback responseCallback);

  /**
   * Adds the {@code listener}. Listeners will be invoked in the same order as they were added
   *
   * @param listener the {@link AuthorizationCodeListener} to be added
   * @throws IllegalArgumentException if the {@code listener} is {@code null}
   * @deprecated since 1.1, 1.0.2. Use {@link #addListener(String, AuthorizationCodeListener)} instead to properly handle the
   *             events corresponding to a resource owner
   */
  @Deprecated
  void addListener(AuthorizationCodeListener listener);

  /**
   * Removes the {@code listener}. Nothing happens if it wasn't part of {@code this} dancer.
   *
   * @param listener the {@link AuthorizationCodeListener} to be removed
   * @throws IllegalArgumentException if the {@code listener} is {@code null}
   * @deprecated since 1.1, 1.0.2. Use {@link #addListener(String, AuthorizationCodeListener)} instead
   */
  @Deprecated
  void removeListener(AuthorizationCodeListener listener);

  /**
   * Adds the {@code listener}. Listeners will be invoked in the same order as they were added
   *
   * @param resourceOwnerId id of the user who the listener corresponds to
   * @param listener        the {@link AuthorizationCodeListener} to be added
   * @throws IllegalArgumentException if the {@code listener} is {@code null}
   *
   * @since 1.1, 1.0.2
   */
  default void addListener(String resourceOwnerId, AuthorizationCodeListener listener) {
    addListener(listener);
  }

  /**
   * Removes the {@code listener}. Nothing happens if it wasn't part of {@code this} dancer.
   *
   * @param resourceOwnerId id of the user who the listener corresponds to
   * @param listener        the {@link AuthorizationCodeListener} to be removed
   * @throws IllegalArgumentException if the {@code listener} is {@code null}
   *
   * @since 1.1, 1.0.2
   */
  default void removeListener(String resourceOwnerId, AuthorizationCodeListener listener) {
    removeListener(listener);
  }

  /**
   * Retrieve ResourceOwnerOAuthContext from tokensStore to check invalidation status of a token.
   * 
   * @param resourceOwner resourceOwner id that is used as key
   * @return true if the token is invalidated.
   *
   * @since 2.3.0
   */
  boolean getInvalidateFromTokensStore(String resourceOwner);

}
